@@ -17,7 +17,7 @@ use YAML::Old qw(Dump LoadFile);    # YAML::XS & YAML::Syck aren't working prope
 # TODO: Standalone script that can be used upstream of any command line functions
 # TODO: Auto-build README using POD
 
-our $VERSION = '0.12.4';
+our $VERSION = '0.12.4_1';
 
 =head1 NAME
 
@@ -124,10 +124,13 @@ EOF
 }
 
 BEGIN {
+    # $previous_PERL_YAML_BACKEND = _set_perl_yaml_backend('YAML');
     _check_for_known_conflicting_modules( '', '' );    # Add when discovered
     _check_for_potentially_conflicting_modules();
 }
 
+my $previous_PERL_YAML_BACKEND = _set_perl_yaml_backend('YAML');
+
 sub import {
     my ( $pkg, $custom_repro_opts ) = @_;
     _reproducibility_is_important($custom_repro_opts);
@@ -718,6 +721,8 @@ sub _exit_code {
             $repro_fh );
         _dump_yaml_to_archive_manually( "ELAPSED", $elapsed, $repro_fh );
         close $repro_fh;
+
+        _set_perl_yaml_backend($previous_PERL_YAML_BACKEND);
     }
 }
 
@@ -733,4 +738,13 @@ sub _elapsed {
     return join ":", map { sprintf "%02d", $_ } $hours, $mins, $secs;
 }
 
+sub _set_perl_yaml_backend {
+    my $new_PERL_YAML_BACKEND = shift;
+
+    my $previous_PERL_YAML_BACKEND = $ENV{PERL_YAML_BACKEND};
+    $ENV{PERL_YAML_BACKEND} = $new_PERL_YAML_BACKEND;
+
+    return $previous_PERL_YAML_BACKEND;
+}
+
 1;
